pub struct AlterTable { /* private fields */ }Expand description
An ALTER TABLE statement.
SQLite accepts one operation per statement, so the builder keeps a single operation and the last setter wins.
Implementations
Sourceimpl AlterTable
impl AlterTable
Sourcepub fn add_column(self, column: ColumnDef) -> Self
pub fn add_column(self, column: ColumnDef) -> Self
Sets the operation to ADD COLUMN.
Sourcepub fn drop_column(self, column: impl IntoIden) -> Self
pub fn drop_column(self, column: impl IntoIden) -> Self
Sets the operation to DROP COLUMN.
Sourcepub fn rename_column(self, from: impl IntoIden, to: impl IntoIden) -> Self
pub fn rename_column(self, from: impl IntoIden, to: impl IntoIden) -> Self
Sets the operation to RENAME COLUMN a TO b.
Sourcepub fn alter_column(self, name: impl IntoIden, column: ColumnDef) -> Self
pub fn alter_column(self, name: impl IntoIden, column: ColumnDef) -> Self
Sets the operation to the Turso extension ALTER COLUMN name TO <new definition>.