Func

Struct Func 

pub struct Func {
    pub name: &'static str,
    pub args: Vec<Expr>,
    pub distinct: bool,
}
A function call.

Fields

name: &'static str

The function name, written verbatim.

args: Vec<Expr>

The arguments.

distinct: bool

Whether DISTINCT applies to the first argument, as in aggregates.

Implementations

Source

impl Func

pub fn call(name: &'static str, args: impl IntoIterator<Item = Expr>) -> Expr

Builds a call to any function.

The name is written verbatim, so this is the escape hatch for engine functions that have no dedicated constructor.

pub fn count(expr: Expr) -> Expr

Builds COUNT(expr).

pub fn count_star() -> Expr

Builds COUNT(*).

pub fn count_distinct(expr: Expr) -> Expr

Builds COUNT(DISTINCT expr).

pub fn max(expr: Expr) -> Expr

Builds MAX(expr).

pub fn min(expr: Expr) -> Expr

Builds MIN(expr).

pub fn sum(expr: Expr) -> Expr

Builds SUM(expr).

pub fn avg(expr: Expr) -> Expr

Builds AVG(expr).

pub fn coalesce(args: impl IntoIterator<Item = Expr>) -> Expr

Builds COALESCE(a, b, ...).

pub fn lower(expr: Expr) -> Expr

Builds LOWER(expr).

pub fn upper(expr: Expr) -> Expr

Builds UPPER(expr).

pub fn length(expr: Expr) -> Expr

Builds LENGTH(expr).

pub fn abs(expr: Expr) -> Expr

Builds ABS(expr).

pub fn if_null(a: Expr, b: Expr) -> Expr

Builds IFNULL(a, b).

pub fn json_extract(json: Expr, path: impl Into<Value>) -> Expr

Builds json_extract(json, path), binding path as a parameter.

pub fn vector_distance_cos(a: Expr, b: Expr) -> Expr

Builds vector_distance_cos(a, b) — Turso vector search.

pub fn vector_distance_l2(a: Expr, b: Expr) -> Expr

Builds vector_distance_l2(a, b) — Turso vector search.

pub fn vector32(expr: Expr) -> Expr

Builds vector32(text) — the Turso vector constructor.

pub fn fts_match(column: Expr, query: impl Into<Value>) -> Expr

Builds fts_match(column, query) — Turso full-text search, binding query as a parameter.

pub fn fts_score(column: Expr) -> Expr

Builds fts_score(column) — Turso full-text search ranking.