IntoIden

Trait IntoIden 

pub trait IntoIden {
    // Required method
    fn into_iden(self) -> Ident;
}
Conversion into an Ident.

Builders take impl IntoIden so that callers can pass a &'static str, a String, an existing Ident or a reference to a derived identifier enum without converting by hand.

Required Methods

fn into_iden(self) -> Ident

Converts into an owned identifier.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoIden for &'static str

Source

impl IntoIden for String

Source

impl<T> IntoIden for &T
where T: IdenOwnedMarker + Iden + ?Sized,

Implementors